/* Definitions to make GDB run on an Alpha box under OSF1.  This is
   also used by the Alpha GNU/Linux target.

   Copyright 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2002, 2004, 2007
   Free Software Foundation, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifndef TM_ALPHA_H
#define TM_ALPHA_H

#define RA_REGNUM 26		/* XXXJRT needed by mdebugread.c */

#endif /* TM_ALPHA_H */
